@@ -72,14 +72,16 @@ class EndTokenRequestView(View):
         Shop = get_shop_model()
         shop_record = Shop.objects.get_or_create(shopify_domain=session.url)[0]
 
-        if not shop_record.shopify_token and access_token:
-            shop_record.installed()
+        installed = bool(not shop_record.shopify_token and access_token)
 
         shop_record.shopify_token = access_token
         shop_record.access_scopes = session.access_scopes
 
         shop_record.save()
 
+        if installed:
+            shop_record.installed()
+
         host = settings.SHOPIFY_APP_HOST
         path = reverse(self.redirect_path_name)
         query = request.META['QUERY_STRING']
